MethodChannelNativeAndroidPath class

An implementation of NativeAndroidPathPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAlarmsPath() → Future<String?>
override
getAllPaths() → Future<Map<String, String?>>
override
getAudiobooksPath() → Future<String?>
override
getDCIMPath() → Future<String?>
override
getDocumentsPath() → Future<String?>
override
getDownloadPath() → Future<String?>
override
getExternalCachePath() → Future<String?>
override
getExternalStorageDirectories(String type) → Future<List<String>>
override
getExternalStoragePath() → Future<String?>
override
getInternalCachePath() → Future<String?>
override
getInternalStoragePath() → Future<String?>
override
getMoviesPath() → Future<String?>
override
getMusicPath() → Future<String?>
override
getNotificationsPath() → Future<String?>
override
getPicturesPath() → Future<String?>
override
getPlatformVersion() → Future<String?>
override
getPodcastsPath() → Future<String?>
override
getRingtonesPath() → Future<String?>
override
getRootInstallationPath() → Future<String?>
override
getScreenshotsPath() → Future<String?>
override
isExternalStorageReadable() → Future<bool>
override
isExternalStorageWritable() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited